# File: trianglengin/trianglengin/core/__init__.py
"""
Core game logic components: environment simulation and data structures.
"""

from . import environment, structs

__all__ = ["environment", "structs"]
